@@ -55,6 +55,7 @@ import ast
 import itertools
 import os
 import re
+from collections import Counter
 
 import astroid
 import rfc3986
@@ -258,6 +259,11 @@ ODOO_MSGS = {
         'context-overridden',
         settings.DESC_DFLT
     ),
+    'W%d25' % settings.BASE_NOMODULE_ID: (
+        'The file "%s" is duplicated %d times from manifest key "%s"',
+        'manifest-data-duplicated',
+        settings.DESC_DFLT
+    ),
     'F%d01' % settings.BASE_NOMODULE_ID: (
         'File "%s": "%s" not found.',
         'resource-not-exist',
@@ -659,8 +665,8 @@ class NoModuleChecker(misc.PylintOdooChecker):
                 if (not is_related and isinstance(argument, astroid.Const) and
                     (index ==
                      FIELDS_METHOD.get(argument.parent.func.attrname, 0)) and
-                    (argument.value in
-                     [field_name.capitalize(), field_name.title()])):
+                    (argument.value ==
+                     field_name.title())):
                     self.add_message('attribute-string-redundant', node=node)
                 if isinstance(argument, astroid.Keyword):
                     argument_aux = argument.value
@@ -676,8 +682,7 @@ class NoModuleChecker(misc.PylintOdooChecker):
                     #   of variable
                     elif not is_related and argument.arg == 'string' and \
                         (isinstance(argument_aux, astroid.Const) and
-                         argument_aux.value in
-                         [field_name.capitalize(), field_name.title()]):
+                         argument_aux.value == field_name.title()):
                         self.add_message(
                             'attribute-string-redundant', node=node)
                     elif (argument.arg in deprecated):
@@ -823,7 +828,7 @@ class NoModuleChecker(misc.PylintOdooChecker):
         'manifest-required-author', 'manifest-required-key',
         'manifest-version-format', 'resource-not-exist',
         'website-manifest-key-not-valid-uri', 'development-status-allowed',
-        'manifest-maintainers-list')
+        'manifest-maintainers-list', 'manifest-data-duplicated')
     def visit_dict(self, node):
         if not os.path.basename(self.linter.current_file) in \
                 settings.MANIFEST_FILES \
@@ -882,9 +887,13 @@ class NoModuleChecker(misc.PylintOdooChecker):
                                    self.config.manifest_version_format_parsed))
 
         # Check if resource exist
+        # Check manifest-data-duplicated
         dirname = os.path.dirname(self.linter.current_file)
         for key in DFTL_MANIFEST_DATA_KEYS:
-            for resource in (manifest_dict.get(key) or []):
+            for resource, coincidences in Counter(manifest_dict.get(key) or []).items():
+                if coincidences >= 2:
+                    self.add_message('manifest-data-duplicated', node=node,
+                                     args=(resource, coincidences, key))
                 if os.path.isfile(os.path.join(dirname, resource)):
                     continue
                 self.add_message('resource-not-exist', node=node,
